Requests was lovingly created by Kenneth Reitz.

Core maintainers
````````````````
- Ahmed Tahri `@Ousret <https://github.com/Ousret>`_.

Previous from Requests
``````````````````````
- Kenneth Reitz <me@kennethreitz.org> `@ken-reitz <https://github.com/ken-reitz>`_, reluctant Keeper of the Master Crystal.
- Cory Benfield <cory@lukasa.co.uk> `@lukasa <https://github.com/lukasa>`_
- Ian Cordasco <graffatcolmingov@gmail.com> `@sigmavirus24 <https://github.com/sigmavirus24>`_.
- Nate Prewitt `@nateprewitt <https://github.com/nateprewitt>`_.
- Seth M. Larson `@sethmlarson <https://github.com/sethmlarson>`_.

Patches and Suggestions
```````````````````````
See https://github.com/jawah/niquests/graphs/contributors
